import React, {useState,useEffect } from 'react'
import { useHistory } from 'react-router-dom'
import { ButtonComponent, InputComponent, TextareaComponent } from '../Utilities/Button/Button'
import { getDataUsingParam,putData } from "../../services/SubModuleService";
import { ProjectDropdown } from '../ProjectComponent/ProjectComponent'
import { ModuleDropdown } from '../ModuleComponent/ModuleComponent'
import *  as Validation from '../Utilities/Validation';
import Alert from '../NotificationComponent/Alert';
import { Astrick } from '../Utilities/Style';

function EditSubModule({match}) {
    const history = useHistory();
    const [subModuleData, setSubsubModuleData] = useState({id:null,project_id:null,module_id:null,sub_module_name:null,description:null,is_active:1});
    const [userData, setUserData] = useState();

    const getData = async (id) => {
        const tempData=[];
        await getDataUsingParam(id).then(res =>{
            if(res.status===200){
                const data=res.data.data[0];
                setSubsubModuleData({
                    project_id: data.project_id,
                    module_id: data.module_id,
                    sub_module_name: data.sub_module_name,
                    description:data.description,
                    is_active : data.is_active,
                });
            }
        });
    }

    const changeHandler =(e)=>{    
        const {name,value}=e.target;
        setSubsubModuleData({
            ...subModuleData,
            [name]: value,
        });
    }
   
    const submitHandler = async (e) => {
        e.preventDefault();
        const data = new FormData(e.target);
        // const form ={};
        // data.forEach((value, key) => {
        //     value=value ? value : null;
        //     form[key]=value 
        // });
        // await putData(match.params.id,form).then(res=>{
        await putData(match.params.id,data).then(res => {
            if(res.status===200){
                const data=res.data;
                var returnValue={show:true,type:"danger",message:data.message};
                if(data.status==1){
                    returnValue.type="success";
                }
                history.push({
                    pathname: '/SubModule',
                    state: { showAlert : true, alertData:returnValue }
                });
            }
        });       
    }
    useEffect(() => {
        getData(match.params.id);
    },[])
    
    return (
        <>
            <div className="body d-flex py-3">
                <div className="container-xxl">
                    <div className="row clearfix g-3">
                        <div className="col-xl-12 col-lg-12 col-md-12 flex-column">
                            {/*************** HEADING ***************/}
                            <div className="card">
                                <div className="card-header d-flex justify-content-between bg-transparent 
                                border-bottom-0">
                                    <h2 className="mb-0 fw-bold ">Edit City</h2>
                                </div>
                            </div>
                            {/*************** TABLE ***************/}
                            <div className='card mt-2'>
                                <div className='card-body'>

                                <form onSubmit={submitHandler}>

                                    <div className="form-group row mt-3">
                                        <label htmlFor="inputEmail3" className="col-sm-2 col-form-label">
                                            <b>Project : <Astrick color='red'/></b>
                                        </label>
                                        <div className="col-sm-10">
                                            <ProjectDropdown id="project_id" name="project_id" 
                                            defaultValue={subModuleData.project_id} 
                                            getChangeValue={changeHandler}
                                            required
                                            />
                                        </div>
                                    </div>

                                    <div className="form-group row mt-3">
                                        <label htmlFor="inputEmail3" className="col-sm-2 col-form-label">
                                            <b>Module : <Astrick color='red'/></b>
                                        </label>
                                        <div className="col-sm-10">
                                            <ModuleDropdown id="module_id" name="module_id" 
                                            defaultValue={subModuleData.project_id} 
                                            getChangeValue={changeHandler}
                                            required
                                            />
                                        </div>
                                    </div>

                                    <div className="form-group row mt-3">
                                        <label htmlFor="inputEmail3" className="col-sm-2 col-form-label">
                                            <b>Module Name : <Astrick color='red'/></b>
                                        </label>
                                        <div className="col-sm-10">
                                            <InputComponent
                                                id="sub_module_name"
                                                name="sub_module_name"
                                                placeholder=""
                                                required={true}
                                                defaultValue={subModuleData.sub_module_name} 
                                                getInputValue={e => { changeHandler(e); } }
                                            />
                                        </div>
                                    </div>

                                    <div className="form-group row mt-2">
                                        <label htmlFor="" className="col-sm-2 col-form-label">
                                            <b>Description : <Astrick color='red'/></b>
                                        </label>
                                        <div className="col-sm-10">
                                            <TextareaComponent
                                                id="description"
                                                name="description"
                                                required={true}
                                                defaultValue={subModuleData.description} 
                                                getInputValue={changeHandler}
                                            />
                                        </div>
                                    </div>
                                    
                                    <div className="mt-3" style={{'textAlign':'right'}}>
                                        <ButtonComponent type="Submit" buttonColor="primary" textColor="white" text="Update"
                                        icon={{type:"Edit",color:"white",size:"15px"}}/>
                                        <ButtonComponent type="Link" url="/SubModule" buttonColor="danger" textColor="white" text="Cancel" 
                                        icon={{type:"Cancel",color:"white",size:"15px"}}/>     
                                    </div>
                                </form>

                                </div>
                            </div>

                        </div>
                    </div> {/*ROW*/}
                </div>{/*CONTAINER*/}
            </div>{/*BODY*/}

        </>
    )
}

export default EditSubModule 
